Struct DmabufState
pub struct DmabufState { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
A handler for zwp_linux_dmabuf_v1::ZwpLinuxDmabufV1
Implementations
impl DmabufState
impl DmabufState
pub fn new<D>(globals: &GlobalList, qh: &QueueHandle<D>) -> DmabufState
pub fn new<D>(globals: &GlobalList, qh: &QueueHandle<D>) -> DmabufState
Bind zwp_linux_dmabuf_v1 global version 3 or 4, if it exists.
This does not fail if the global does not exist.
pub fn modifiers(&self) -> &[DmabufFormat]
pub fn modifiers(&self) -> &[DmabufFormat]
Only populated in version <4
On version 4, use DmabufState::get_surface_feedback.
pub fn create_params<D>(
&self,
qh: &QueueHandle<D>,
) -> Result<DmabufParams, GlobalError>
pub fn create_params<D>( &self, qh: &QueueHandle<D>, ) -> Result<DmabufParams, GlobalError>
Create a params object for constructing a buffer
Errors if zwp_linux_dmabuf_v1 does not exist or has unsupported
version. An application can then fallback to using shm buffers.
pub fn get_default_feedback<D>(
&self,
qh: &QueueHandle<D>,
) -> Result<ZwpLinuxDmabufFeedbackV1, GlobalError>where
D: Dispatch<ZwpLinuxDmabufFeedbackV1, DmabufFeedbackData> + 'static,
pub fn get_default_feedback<D>(
&self,
qh: &QueueHandle<D>,
) -> Result<ZwpLinuxDmabufFeedbackV1, GlobalError>where
D: Dispatch<ZwpLinuxDmabufFeedbackV1, DmabufFeedbackData> + 'static,
Get default dmabuf feedback. Requires version 4.
On version 3, use DmabufState::modifiers.
pub fn get_surface_feedback<D>(
&self,
surface: &WlSurface,
qh: &QueueHandle<D>,
) -> Result<ZwpLinuxDmabufFeedbackV1, GlobalError>where
D: Dispatch<ZwpLinuxDmabufFeedbackV1, DmabufFeedbackData> + 'static,
pub fn get_surface_feedback<D>(
&self,
surface: &WlSurface,
qh: &QueueHandle<D>,
) -> Result<ZwpLinuxDmabufFeedbackV1, GlobalError>where
D: Dispatch<ZwpLinuxDmabufFeedbackV1, DmabufFeedbackData> + 'static,
Get default dmabuf feedback for given surface. Requires version 4.
On version 3, use DmabufState::modifiers.